Learn R Programming

distributional (version 0.3.0)

autoplot.distribution: Plot a distribution

Description

lifecycle::badge("deprecated")

Usage

autoplot.distribution(x, ...)

Arguments

x

The distribution(s) to plot.

...

Unused.

Details

This function is now defunct and can no longer be used. Instead consider using the ggdist package to produce your own distribution plots. You can learn more about how this plot can be produced using ggdist here: https://mjskay.github.io/ggdist/articles/slabinterval.html