dist_burr: The Burr distribution

View source: R/dist_burr.R

dist_burrR Documentation

The Burr distribution

Description

[Stable]

The Burr distribution (Type XII) is a flexible continuous probability distribution often used for modeling income distributions, reliability data, and failure times.

Usage

dist_burr(shape1, shape2, rate = 1, scale = 1/rate)

Arguments

shape1, shape2, scale

parameters. Must be strictly positive.

rate

an alternative way to specify the scale.

Details

We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_burr.html

In the following, let X be a Burr random variable with parameters shape1 = \alpha, shape2 = \gamma, and rate = \lambda.

Support: x \in (0, \infty)

Mean: \frac{\lambda^{-1/\alpha} \gamma B(\gamma - 1/\alpha, 1 + 1/\alpha)}{\gamma} (for \alpha \gamma > 1)

Variance: \frac{\lambda^{-2/\alpha} \gamma B(\gamma - 2/\alpha, 1 + 2/\alpha)}{\gamma} - \mu^2 (for \alpha \gamma > 2)

Probability density function (p.d.f):

f(x) = \alpha \gamma \lambda x^{\alpha - 1} (1 + \lambda x^\alpha)^{-\gamma - 1}

Cumulative distribution function (c.d.f):

F(x) = 1 - (1 + \lambda x^\alpha)^{-\gamma}

Quantile function:

F^{-1}(p) = \lambda^{-1/\alpha} ((1 - p)^{-1/\gamma} - 1)^{1/\alpha}

Moment generating function (m.g.f):

Does not exist in closed form.

See Also

actuar::Burr

Examples

dist <- dist_burr(shape1 = c(1,1,1,2,3,0.5), shape2 = c(1,2,3,1,1,2))
dist


mean(dist)
variance(dist)
support(dist)
generate(dist, 10)

density(dist, 2)
density(dist, 2, log = TRUE)

cdf(dist, 4)

quantile(dist, 0.7)


distributional documentation built on June 11, 2026, 9:07 a.m.