dist_geometric: The Geometric Distribution

View source: R/dist_geometric.R

dist_geometricR Documentation

The Geometric Distribution

Description

[Stable]

The Geometric distribution can be thought of as a generalization of the dist_bernoulli() distribution where we ask: "if I keep flipping a coin with probability p of heads, what is the probability I need k flips before I get my first heads?" The Geometric distribution is a special case of Negative Binomial distribution.

Usage

dist_geometric(prob)

Arguments

prob

probability of success in each trial. 0 < prob <= 1.

Details

We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_geometric.html

In the following, let X be a Geometric random variable with success probability prob = p. Note that there are multiple parameterizations of the Geometric distribution.

Support: \{0, 1, 2, 3, ...\}

Mean: \frac{1-p}{p}

Variance: \frac{1-p}{p^2}

Probability mass function (p.m.f):

P(X = k) = p(1-p)^k

Cumulative distribution function (c.d.f):

P(X \le k) = 1 - (1-p)^{k+1}

Moment generating function (m.g.f):

E(e^{tX}) = \frac{pe^t}{1 - (1-p)e^t}

Skewness:

\frac{2 - p}{\sqrt{1 - p}}

Excess Kurtosis:

6 + \frac{p^2}{1 - p}

See Also

stats::Geometric

Examples

dist <- dist_geometric(prob = c(0.2, 0.5, 0.8))

dist
mean(dist)
variance(dist)
skewness(dist)
kurtosis(dist)

generate(dist, 10)

density(dist, 2)
density(dist, 2, log = TRUE)

cdf(dist, 4)

quantile(dist, 0.7)

distributional documentation built on June 27, 2026, 5:06 p.m.