dist_gumbel: The Gumbel distribution

View source: R/dist_gumbel.R

dist_gumbelR Documentation

The Gumbel distribution

Description

[Stable]

The Gumbel distribution is a special case of the Generalized Extreme Value distribution, obtained when the GEV shape parameter \xi is equal to 0. It may be referred to as a type I extreme value distribution.

Usage

dist_gumbel(alpha, scale)

Arguments

alpha

location parameter.

scale

parameter. Must be strictly positive.

Details

We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_gumbel.html

In the following, let X be a Gumbel random variable with location parameter alpha = \alpha and scale parameter scale = \sigma.

Support: R, the set of all real numbers.

Mean:

E(X) = \alpha + \sigma\gamma

where \gamma is the Euler-Mascheroni constant, approximately equal to 0.5772157.

Variance:

\textrm{Var}(X) = \frac{\pi^2 \sigma^2}{6}

Skewness:

\textrm{Skew}(X) = \frac{12\sqrt{6}\zeta(3)}{\pi^3} \approx 1.1395

where \zeta(3) is Apery's constant, approximately equal to 1.2020569. Note that skewness is independent of the distribution parameters.

Kurtosis (excess):

\textrm{Kurt}(X) = \frac{12}{5} = 2.4

Note that excess kurtosis is independent of the distribution parameters.

Median:

\textrm{Median}(X) = \alpha - \sigma\ln(\ln 2)

Probability density function (p.d.f):

f(x) = \frac{1}{\sigma} \exp\left[-\frac{x - \alpha}{\sigma}\right] \exp\left\{-\exp\left[-\frac{x - \alpha}{\sigma}\right]\right\}

for x in R, the set of all real numbers.

Cumulative distribution function (c.d.f):

F(x) = \exp\left\{-\exp\left[-\frac{x - \alpha}{\sigma}\right]\right\}

for x in R, the set of all real numbers.

Quantile function (inverse c.d.f):

F^{-1}(p) = \alpha - \sigma \ln(-\ln p)

for p in (0, 1).

Moment generating function (m.g.f):

E(e^{tX}) = \Gamma(1 - \sigma t) e^{\alpha t}

for \sigma t < 1, where \Gamma is the gamma function.

See Also

actuar::Gumbel, actuar::dgumbel(), actuar::pgumbel(), actuar::qgumbel(), actuar::rgumbel(), actuar::mgumbel()

Examples

dist <- dist_gumbel(alpha = c(0.5, 1, 1.5, 3), scale = c(2, 2, 3, 4))
dist


mean(dist)
variance(dist)
skewness(dist)
kurtosis(dist)
support(dist)
generate(dist, 10)

density(dist, 2)
density(dist, 2, log = TRUE)

cdf(dist, 4)

quantile(dist, 0.7)


distributional documentation built on June 27, 2026, 5:06 p.m.