dist_studentized_range: The Studentized Range distribution

View source: R/dist_studentized_range.R

dist_studentized_rangeR Documentation

The Studentized Range distribution

Description

[Stable]

Tukey's studentized range distribution, used for Tukey's honestly significant differences test in ANOVA.

Usage

dist_studentized_range(nmeans, df, nranges)

Arguments

nmeans

sample size for range (same for each group).

df

degrees of freedom for s (see below).

nranges

number of groups whose maximum range is considered.

Details

We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_studentized_range.html

In the following, let Q be a Studentized Range random variable with parameters nmeans = k (number of groups), df = \nu (degrees of freedom), and nranges = n (number of ranges).

Support: R^+, the set of positive real numbers.

Mean: Approximated numerically.

Variance: Approximated numerically.

Probability density function (p.d.f): The density does not have a closed-form expression and is computed numerically.

Cumulative distribution function (c.d.f): The c.d.f does not have a simple closed-form expression. For n = 1 (single range), it involves integration over the joint distribution of the sample range and an independent chi-square variable. The general form is computed numerically using algorithms described in the references for stats::ptukey().

Moment generating function (m.g.f): Does not exist in closed form.

See Also

stats::Tukey

Examples

dist <- dist_studentized_range(nmeans = c(6, 2), df = c(5, 4), nranges = c(1, 1))

dist

cdf(dist, 4)

quantile(dist, 0.7)


distributional documentation built on June 11, 2026, 9:07 a.m.