dist_uniform: The Uniform distribution

View source: R/dist_uniform.R

dist_uniformR Documentation

The Uniform distribution

Description

[Stable]

A distribution with constant density on an interval.

Usage

dist_uniform(min, max)

Arguments

min, max

lower and upper limits of the distribution. Must be finite.

Details

We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_uniform.html

In the following, let X be a Uniform random variable with parameters min = a and max = b.

Support: [a, b]

Mean: \frac{a + b}{2}

Variance: \frac{(b - a)^2}{12}

Probability density function (p.d.f):

f(x) = \frac{1}{b - a}

for x \in [a, b], and f(x) = 0 otherwise.

Cumulative distribution function (c.d.f):

F(x) = \frac{x - a}{b - a}

for x \in [a, b], with F(x) = 0 for x < a and F(x) = 1 for x > b.

Moment generating function (m.g.f):

E(e^{tX}) = \frac{e^{tb} - e^{ta}}{t(b - a)}

for t \neq 0, and E(e^{tX}) = 1 for t = 0.

Skewness: 0

Excess Kurtosis: -\frac{6}{5}

See Also

stats::Uniform

Examples

dist <- dist_uniform(min = c(3, -2), max = c(5, 4))

dist
mean(dist)
variance(dist)
skewness(dist)
kurtosis(dist)

generate(dist, 10)

density(dist, 2)
density(dist, 2, log = TRUE)

cdf(dist, 4)

quantile(dist, 0.7)


distributional documentation built on June 11, 2026, 9:07 a.m.