| has_symmetry | R Documentation |
Determines whether a probability distribution is symmetric around its center.
has_symmetry(x, ...)
x |
The distribution(s). |
... |
Additional arguments used by methods. |
A logical value indicating whether the distribution is symmetric.
# Normal distribution is symmetric
has_symmetry(dist_normal(mu = 0, sigma = 1))
has_symmetry(dist_normal(mu = 5, sigma = 2))
# Beta distribution symmetry depends on parameters
has_symmetry(dist_beta(shape1 = 2, shape2 = 2)) # symmetric
has_symmetry(dist_beta(shape1 = 2, shape2 = 5)) # not symmetric
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.