hilo.distribution: Probability intervals of a probability distribution
Description
lifecycle::badge("maturing")
Usage
# S3 method for distribution
hilo(x, size = 95, ...)
Arguments
- x
The distribution(s).
- size
The size of the interval (between 0 and 100).
- ...
Additional arguments used by methods.
Details
Returns a hilo central probability interval with probability coverage of
size. By default, the distribution's quantile() will be used to compute
the lower and upper bound for a centered interval