dist_inverse_exponential: The Inverse Exponential distribution

View source: R/dist_inverse_exponential.R

dist_inverse_exponentialR Documentation

The Inverse Exponential distribution

Description

[Stable]

The Inverse Exponential distribution is used to model the reciprocal of exponentially distributed variables.

Usage

dist_inverse_exponential(rate)

Arguments

rate

an alternative way to specify the scale.

Details

We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_inverse_exponential.html

In the following, let X be an Inverse Exponential random variable with parameter rate = \lambda.

Support: x > 0

Mean: Does not exist, returns NA

Variance: Does not exist, returns NA

Probability density function (p.d.f):

f(x) = \frac{\lambda}{x^2} e^{-\lambda/x}

Cumulative distribution function (c.d.f):

F(x) = e^{-\lambda/x}

Quantile function (inverse c.d.f):

F^{-1}(p) = -\frac{\lambda}{\log(p)}

Moment generating function (m.g.f):

Does not exist (divergent integral).

See Also

actuar::InverseExponential

Examples

dist <- dist_inverse_exponential(rate = 1:5)
dist


mean(dist)
variance(dist)
support(dist)
generate(dist, 10)

density(dist, 2)
density(dist, 2, log = TRUE)

cdf(dist, 4)

quantile(dist, 0.7)


distributional documentation built on June 11, 2026, 9:07 a.m.