The log-normal distribution is a commonly used transformation of the Normal
distribution. If \(X\) follows a log-normal distribution, then \(\ln{X}\)
would be characteristed by a Normal distribution.
We recommend reading this documentation on
https://pkg.mitchelloharawild.com/distributional/, where the math
will render nicely.
In the following, let \(Y\) be a Normal random variable with mean
mu = \(\mu\) and standard deviation sigma = \(\sigma\). The
log-normal distribution \(X = exp(Y)\) is characterised by:
Support: \(R+\), the set of all real numbers greater than or equal to 0.
Mean: \(e^(\mu + \sigma^2/2\)
Variance: \((e^(\sigma^2)-1) e^(2\mu + \sigma^2\)
Probability density function (p.d.f):
$$
f(x) = \frac{1}{x\sqrt{2 \pi \sigma^2}} e^{-(\ln{x} - \mu)^2 / 2 \sigma^2}
$$
Cumulative distribution function (c.d.f):
The cumulative distribution function has the form
$$
F(x) = \Phi((\ln{x} - \mu)/\sigma)
$$
Where \(Phi\) is the CDF of a standard Normal distribution, N(0,1).