| dist_missing | R Documentation |
A placeholder distribution for handling missing values in a vector of distributions.
dist_missing(length = 1)
length |
The number of missing distributions |
We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_missing.html
The missing distribution represents the absence of distributional
information. It is used as a placeholder when distribution values are
not available or not applicable, similar to how NA is used for missing
scalar values.
Support: Undefined
Mean: \text{NA}
Variance: \text{NA}
Skewness: \text{NA}
Kurtosis: \text{NA}
Probability density function (p.d.f): Undefined
f(x) = \text{NA}
Cumulative distribution function (c.d.f): Undefined
F(t) = \text{NA}
Quantile function: Undefined
Q(p) = \text{NA}
Moment generating function (m.g.f): Undefined
E(e^{tX}) = \text{NA}
All statistical operations on missing distributions return NA values
of appropriate length, propagating the missingness through calculations.
base::NA
dist <- dist_missing(3L)
dist
mean(dist)
variance(dist)
generate(dist, 10)
density(dist, 2)
density(dist, 2, log = TRUE)
cdf(dist, 4)
quantile(dist, 0.7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.