| dist_pareto | R Documentation |
The Pareto distribution is a power-law probability distribution commonly used in actuarial science to model loss severity and in economics to model income distributions and firm sizes.
dist_pareto(shape, scale)
shape, scale |
parameters. Must be strictly positive. |
We recommend reading this documentation on pkgdown which renders math nicely. https://pkg.mitchelloharawild.com/distributional/reference/dist_pareto.html
In the following, let X be a Pareto random variable with parameters
shape = \alpha and scale = \theta.
Support: (0, \infty)
Mean: \frac{\theta}{\alpha - 1} for \alpha > 1,
undefined otherwise
Variance: \frac{\alpha\theta^2}{(\alpha - 1)^2(\alpha - 2)}
for \alpha > 2, undefined otherwise
Probability density function (p.d.f):
f(x) = \frac{\alpha\theta^\alpha}{(x + \theta)^{\alpha + 1}}
for x > 0, \alpha > 0 and \theta > 0.
Cumulative distribution function (c.d.f):
F(x) = 1 - \left(\frac{\theta}{x + \theta}\right)^\alpha
for x > 0.
Moment generating function (m.g.f):
Does not exist in closed form, but the kth raw moment E[X^k] exists
for -1 < k < \alpha.
There are many different definitions of the Pareto distribution in the literature; see Arnold (2015) or Kleiber and Kotz (2003). This implementation uses the Pareto distribution without a location parameter as described in actuar::Pareto.
Kleiber, C. and Kotz, S. (2003), Statistical Size Distributions in Economics and Actuarial Sciences, Wiley.
Klugman, S. A., Panjer, H. H. and Willmot, G. E. (2012), Loss Models, From Data to Decisions, Fourth Edition, Wiley.
actuar::Pareto
dist <- dist_pareto(shape = c(10, 3, 2, 1), scale = rep(1, 4))
dist
mean(dist)
variance(dist)
support(dist)
generate(dist, 10)
density(dist, 2)
density(dist, 2, log = TRUE)
cdf(dist, 4)
quantile(dist, 0.7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.